package Src;
import java.io.* ;

/**
 *  Classe permettant de lire un fichier de sommets.
 *
 *  Chaque ligne du fichier est de la forme :
 *  7:1.3890,43.6360,251:TOULOUSE
 *  num???ro de sommet:longitude:latitude:altitude:nom du lieu
 */

public class LecteurSommets {

    private BufferedReader in ;
    private boolean open ;
    private String Filename ;
    private int linenb ;

    /** Contient le num???ro du sommet courant. */
    public int numeroSommet ;

    /** Contient la longitude du sommet courant, en degr???s. */
    public double longitude ;

    /** Contient la latitude du sommet courant, en degr???s. */
    public double latitude ;

    /** Contient l'altitude du sommet courant, en m???tres, par rapport au g???o???de EGM96. */
    public int altitude ;

    /** Contient le nom du sommet courant, la cha???ne vide si son nom est inconnu. */
    public String nom ;



    /**
     * @param  Filename  Nom du fichier contenant les sommets.
     */
    public LecteurSommets (String Filename) throws FileNotFoundException{
	this.Filename = Filename ;
	this.in = new BufferedReader(new FileReader(Filename)) ;
	this.open = true ;
	this.linenb = 0 ;
    }



    /**
     * Lit le sommet suivant dans le fichier.
     * Les champs du sommet sont places dans les attributs de l'objet.
     * Cette methode peut etre invoquee sans risque d'erreur meme s'il ne reste plus de sommets e lire.
     *
     * @return      true si un sommet a bien ete lu.
     */

    public boolean sommetSuivant () {
	if (this.open) {
	    try {
		String line = in.readLine () ;
		if (line == null) return false ;

		line = line.trim () ;
		linenb = linenb + 1 ;

		if ((line.length () == 0) || (this.is_comment (line)) ) { return this.sommetSuivant () ; }

		String[] splits = line.split (":", 3) ;
		
		this.numeroSommet = this.get_int ("du num??ro de sommet", splits[0]) ;
		
		String[] coords = splits[1].split (",", 3);
		this.longitude = this.get_float ("de la longitude", coords[0]) ;
		this.latitude  = this.get_float ("de la latitude", coords[1]) ;
		this.altitude  = this.get_int   ("de l'altitude", coords[2]) ;
		
		this.nom = splits[2] ;
		return true ;
	    }
	    catch (IOException e) {
		open = false ;
		try { in.close () ; } catch (IOException ee) {}
		return false ;
	    }
	}
	else return false ;
    }

    private int get_int (String champ, String v) {
	try {return ((new Integer (v)).intValue ()) ;}
	catch (NumberFormatException e) {
	    System.err.println("Fichier " + Filename + ", ligne " + linenb + " : erreur de lecture " + champ) ;
	    return 0 ;
	}
    }

    private double get_float (String champ, String v) {
	try {return ((new Double (v)).doubleValue ()) ;}
	catch (NumberFormatException e) {
	    System.err.println("Fichier " + Filename + ", ligne " + linenb + " : erreur de lecture " + champ) ;
	    return 0.0 ;
	}
    }

    private boolean is_comment (String line) {
	return line.startsWith("//") ;
    }

   // public static void main(String[] args) throws FileNotFoundException {
    public static void lireSommet(String nomFic, Graphe graph) throws FileNotFoundException {
    	LecteurSommets lect = new LecteurSommets (nomFic) ;
		while (lect.sommetSuivant()) {

	//    System.out.println ("Sommet " + lect.numeroSommet + " (" + lect.longitude + ", " +
		//		lect.latitude + ", " + lect.altitude + ")  " + lect.nom) ;
		graph.insererSommet(new Sommet(lect.numeroSommet, (float)lect.longitude, (float)lect.latitude, lect.altitude, lect.nom));
		}
    }
    
    public static int lireNbSommet(String nomFic) throws FileNotFoundException {
    	int nbSommet =0;
    	LecteurSommets lect = new LecteurSommets (nomFic) ;
    	while (lect.sommetSuivant()) {
    		nbSommet++;
    	   /* System.out.println ("Sommet " + lect.numeroSommet + " (" + lect.longitude + ", " +
    				lect.latitude + ", " + lect.altitude + ")  " + lect.nom) ;*/
    	}
    	return nbSommet;
    }

}